@@ -7,6 +7,7 @@ import time
 import argparse
 from typing import List
 from blessings import Terminal
+from colors import *
 import pyfiglet
 import gitlab
 import yaml
@@ -89,6 +90,7 @@ class facile_trigger_helper(object):
             facile_trigger = pyfiglet.figlet_format("facile.it Trigger Helper", font = "doom"  ) 
             print(term.bold_cyan(facile_trigger))
             print("Running robot path: " + robot_path)
+            print(color('gilab should be clored', fg='blue'))
             self.trigger_pipeline(robot_path, git_lab_host, 
             api_gilab_token, target_branch, project_id)
 
